@@ -6,9 +6,22 @@
 
 # GlobalChemExtensions Import
 
+# Visualization
+
 from global_chem_extensions.sunburster.sunburster import Sunburster
+
+# Analytics
+
 from global_chem_extensions.node_pca_analysis.node_pca_analysis import PCAAnalysis
 
+# Converters
+
+from global_chem_extensions.amino_acid_converter.amino_acid_converter import AminoAcidConverter
+
+# Monitors
+
+from global_chem_extensions.database_monitor.database_monitor import DatabaseMonitor
+
 class ExtensionsError(Exception):
 
     __version_error_parser__ = "0.0.1"
@@ -95,7 +108,68 @@ class GlobalChemExtensions(object):
         if return_mol_ids:
             return return_mol_ids
 
+    @staticmethod
+    def smiles_to_amino_acids(
+            smiles_list
+    ):
 
+        '''
 
+        Arguments:
+            smiles_list (List): List of the SMILES
 
+        Returns:
+            converted_list (List): Converted list of the SMILES to the amino acid converters
 
+        '''
+
+        converter = AminoAcidConverter()
+
+        converted_list = []
+
+        for smiles in smiles_list:
+
+            converted_list.append(
+                converted_list.append(converter.convert_smiles_to_amino_acid_sequence(smiles))
+            )
+
+        return converted_list
+
+    @staticmethod
+    def amino_acids_to_smiles(
+            amino_acid_list
+    ):
+
+        '''
+
+        Arguments:
+            amino_acid_list (List): List of the Amino Acids
+
+        Returns:
+            converted_list (List): Converted list of the SMILES to the amino acid converters
+
+        '''
+
+        converter = AminoAcidConverter()
+
+        converted_list = []
+
+        for amino_acid in amino_acid_list:
+
+            converted_list.append(
+                converter.convert_amino_acid_sequence_to_smiles(amino_acid)
+            )
+
+        return converted_list
+
+    @staticmethod
+    def check_status_on_open_source_databases():
+
+        '''
+
+        Check the Status on Databases
+
+        '''
+
+        database_monitor = DatabaseMonitor()
+        database_monitor.heartbeat()
